==> hexbin_1.0.3.tar.gz: hexbin/man/hdiffplot.Rd <==
\name{hdiffplot}
\alias{hdiffplot}
\title{Plot of Domain and Median Differences of Two `hbin' Objects}
\description{
  Let hbin1 and hbin2 represent two hexbin objects with scaling, plot
  shapes, and bin sizes. This plot distinguishes cells unique to hbin1,
  cells in common, and cells unique to hbin2 using color.  When the
  erode components are present, color also distinguishes the two erosion
  medians.  An arrow shows the vector from the median of hbin1 to the
  median of hbin2.
}

\usage{
hdiffplot(bin1, bin2, xbnds, ybnds, density,
          border = rep(FALSE, 6), pen = 2:7, size = 0.1, lwd = 2,
          eps = 1e-6, unzoom = 1.04,
          xlab = "", ylab = "", main = deparse(mycall), ...)
}

\arguments{
  \item{bin1}{an object of type hexbin.}
  \item{bin2}{an object of type hexbin.}
  \item{xbnds}{global x-axis plotting limits.  Used primarily for
    multiple comparison plots.}
  \item{ybnds}{global y-axis plotting limits.  Used primarily for
    multiple comparison plots. }
  \item{density}{fill arguments to polygon}
  \item{border}{border arguments to polygon}
  \item{pen}{pen numbers for polgyon}
  \item{size}{arrow type size in inches.}
  \item{eps}{distance criteria for distinct medians}
  \item{unzoom}{plot limit expansion factor when xbnds is missing}
%%%------- FIXME --------
  \item{lwd}{To be added}
  \item{xlab}{To be added}
  \item{ylab}{To be added}
  \item{main}{main title for the plot; automatically constructed by default.}
  \item{...}{To be added}
}

\value{
invisible("Done")
}

\details{
  The hexbin objects for comparison, \code{hbin1} and \code{hbin2}, must
  have the same plotting limits and cell size.  The plot produces a
  comparison overlay of the cells in the two objects.  If external
  global scaling is not supplied, the algorithm determines plotting
  limits to increase resolution.  For example, the objects may be the
  result of the \code{\link{erode.hexbin}()} and include only high count cells
  containing 50 of the counts.  The density, border, and pen arguments
  correspond to the polygon function calls for plotting six types of
  cells.  The cell types are respectively:
  \tabular{l}{
    unique cells of hbin1,\cr
    joint cells,\cr
    unique cells of hbin2,\cr
    median cell of hbin1,\cr
    median cell of hbin2,\cr
    median cell if identical.\cr
  }

  The \code{erode} components of the hexbin objects must be present for the
  medians to plot.  The algorithm select a single cell for the median if
  there are algorithmic ties.

  The \code{pen} numbers for types of cells start at Pen 2.  Pen 1 is
  presumed black.  The suggested six additional colors are light blue,
  light gray, light red, blue, red, and black.  The reference below
  %% Carr (1991)
  shows an example for black and white printing.  That plot changes the
  six colors to light gray, dark gray, white, black, black, and black.
  It changes the 4th, 5th, and 6th argument of border to TRUE.  It also
  changes 4th, 5th and 6th argument of density to 0.  In other words
  cells in common do not show and medians cells appear as outlines.

  When \code{xbnds} is missing, the plot changes graphics parameters and resets
  them.   The function also zooms in based on the available data to
  provide increased resolution.
}

\references{ see in \code{\link{hexagons}}.}%>> ./hexagons.Rd

\seealso{
  \code{\link{hexbin}}, \code{\link{smooth.hexbin}}, \code{\link{erode.hexbin}}, % MISSING: hthin,
  \code{\link{hcell2xy}}, \code{\link{hcell}}, \code{\link{plot.hexbin}},
  \code{\link{hboxplot}}, \code{\link{hmatplot}},
  \code{\link{hexagons}}, \code{\link{hex.legend}}.
}

\examples{
#  Comparison of two bivariate boxplots
x1 <- rnorm(10000)
y1 <- rnorm(10000)
x2 <- rnorm(10000,mean=.3)
y2 <- rnorm(10000,mean=.3)
xbnds <- range(x1,x2)
ybnds <- range(y2,y2)

bin1 <- hexbin(x1,y1,xbnds=xbnds,ybnds=ybnds)
bin2 <- hexbin(x2,y2,xbnds=xbnds,ybnds=ybnds)
erodebin1 <- erode.hexbin(smooth.hexbin(bin1))
erodebin2 <- erode.hexbin(smooth.hexbin(bin2))

hdiffplot(erodebin1,erodebin2)
}

\keyword{hplot}

==> hexbin_1.0.8.tar.gz: hexbin/man/hdiffplot.Rd <==
\name{hdiffplot}
\alias{hdiffplot}
\title{Plot of Domain and Median Differences of Two `hbin' Objects}
\description{
  Let hbin1 and hbin2 represent two hexbin objects with scaling, plot
  shapes, and bin sizes. This plot distinguishes cells unique to hbin1,
  cells in common, and cells unique to hbin2 using color.  When the
  erode components are present, color also distinguishes the two erosion
  medians.  An arrow shows the vector from the median of hbin1 to the
  median of hbin2.
}

\usage{
hdiffplot(bin1, bin2, xbnds, ybnds,
          density = rep.int(-1, 6), border = rep.int(FALSE, 6), pen = 2:7,
          size = 0.1, lwd = 2, eps = 1e-6, unzoom = 1.04,
          xlab = "", ylab = "", main = deparse(mycall), \dots)
}

\arguments{
  \item{bin1}{an object of type hexbin.}
  \item{bin2}{an object of type hexbin.}
  \item{xbnds}{global x-axis plotting limits.  Used primarily for
    multiple comparison plots.}
  \item{ybnds}{global y-axis plotting limits.  Used primarily for
    multiple comparison plots. }
  \item{density}{fill arguments to polygon}
  \item{border}{border arguments to polygon}
  \item{pen}{pen numbers for polgyon}
  \item{size}{arrow type size in inches.}
  \item{eps}{distance criteria for distinct medians}
  \item{unzoom}{plot limit expansion factor when xbnds is missing}
%%%------- FIXME --------
  \item{lwd}{To be added}
  \item{xlab}{To be added}
  \item{ylab}{To be added}
  \item{main}{main title for the plot; automatically constructed by default.}
  \item{\dots}{To be added}
}

\value{
invisible("Done")
}

\details{
  The hexbin objects for comparison, \code{hbin1} and \code{hbin2}, must
  have the same plotting limits and cell size.  The plot produces a
  comparison overlay of the cells in the two objects.  If external
  global scaling is not supplied, the algorithm determines plotting
  limits to increase resolution.  For example, the objects may be the
  result of the \code{\link{erode.hexbin}()} and include only high count cells
  containing 50 of the counts.  The density, border, and pen arguments
  correspond to the polygon function calls for plotting six types of
  cells.  The cell types are respectively:
  \tabular{l}{
    unique cells of hbin1,\cr
    joint cells,\cr
    unique cells of hbin2,\cr
    median cell of hbin1,\cr
    median cell of hbin2,\cr
    median cell if identical.\cr
  }

  The \code{erode} components of the hexbin objects must be present for the
  medians to plot.  The algorithm select a single cell for the median if
  there are algorithmic ties.

  The \code{pen} numbers for types of cells start at Pen 2.  Pen 1 is
  presumed black.  The suggested six additional colors are light blue,
  light gray, light red, blue, red, and black.  The reference below
  %% Carr (1991)
  shows an example for black and white printing.  That plot changes the
  six colors to light gray, dark gray, white, black, black, and black.
  It changes the 4th, 5th, and 6th argument of border to TRUE.  It also
  changes 4th, 5th and 6th argument of density to 0.  In other words
  cells in common do not show and medians cells appear as outlines.

  When \code{xbnds} is missing, the plot changes graphics parameters and resets
  them.   The function also zooms in based on the available data to
  provide increased resolution.
}

\references{ see in \code{\link{hexagons}}.}%>> ./hexagons.Rd

\seealso{
  \code{\link{hexbin}}, \code{\link{smooth.hexbin}}, \code{\link{erode.hexbin}}, % MISSING: hthin,
  \code{\link{hcell2xy}}, \code{\link{hcell}}, \code{\link{plot.hexbin}},
  \code{\link{hboxplot}}, \code{\link{hmatplot}},
  \code{\link{hexagons}}, \code{\link{hex.legend}}.
}

\examples{
#  Comparison of two bivariate boxplots
x1 <- rnorm(10000)
y1 <- rnorm(10000)
x2 <- rnorm(10000,mean=.3)
y2 <- rnorm(10000,mean=.3)
xbnds <- range(x1,x2)
ybnds <- range(y2,y2)

bin1 <- hexbin(x1,y1,xbnds=xbnds,ybnds=ybnds)
bin2 <- hexbin(x2,y2,xbnds=xbnds,ybnds=ybnds)
erodebin1 <- erode.hexbin(smooth.hexbin(bin1))
erodebin2 <- erode.hexbin(smooth.hexbin(bin2))

hdiffplot(erodebin1,erodebin2)
}

\keyword{hplot}
